#########################################################################################
#### Acquired Settings:
#########################################################################################

## The settings acquired in this interface are distributed in three lists (one per frame
## of the layout). The first is SETDataLayout which contains the following settings:
## - platenumber: numerical value defining the number of plates to analyse
## - multiple: logical value, whether the data for the plates is found in one or multiple plates
## - missingValues: logical value, FALSE if non-numerical data was already removed
## - timescale: numerical value defining the input time scale
## - inputunit: character string defining the specific platform used
## The timescale setting was moved to the general formatting tab in the analysis options,
## but is still stored in this list for version compatibility. In the base version
## the inputunit setting is not used and can not be changed, since there are no platform
## specific analyses accessible.
SETDataLayout <- list(	platenumber = 2,
						multiple = FALSE,
						missingValues = 0,
						timescale = 1,
						inputunit = "none" )
#### The second list SETBorders holds all values necessary to select the range of cells
## to import from the given files. Those are:
## - header: logical value, whether there is a header above the actual data
## - rowsTop: numerical value telling how big the header is
## - remove: logical value, if FALSE the headers will be saved to a separate file
## - removeStart: numerical value giving the number of columns to remove to the left
## - removeEnd: numerical value giving the number of columns to remove to the right
## - rowsEnd: numerical value giving the number of rows to remove in the end
SETBorders <- list(	header = FALSE,
					rowsTop = 10,
					remove = TRUE,
					removeStart = 1,
					removeEnd = 2,
					rowsEnd = 0 )
## The third list contains the information about the files to be loaded. Here "files"
## is a vector of length platenumber (if multiple is TRUE) or one (if multiple is 
## FALSE), containing the full path to the files. "wells" is a vector of length
## platenumber containing the number of wells found in each plate. "separator" gives the
## table cell separator and "decimal" is the decimal separator.
SETFilesInput <- list(	files = c(),
						wells = c(),
						separator = ";",
						decimal = "," )

#########################################################################################
#### Layout and Interface Definition for Data Input
#########################################################################################

####
#### Frame layout
#################

## The interface is separated into three frames - one for the general data layout selection,
## one for the number of rows / columns to cut and one for the actual file names and
## well numbers.

FRLayout <- gtkFrame("Data layout")
FRBorders <- gtkFrame("Cutting borders")
FRFilesInput <- gtkFrame("File import")

# layout for left half of the center frame
layoutDataInputLeft <- gtkVBox(FALSE, 5)
	layoutDataInputLeft$packStart(FRLayout, expand = FALSE, fill = FALSE)
	layoutDataInputLeft$packStart(FRBorders, expand = FALSE, fill = FALSE)

# layout for right half of the center frame
layoutDataInputRight <- gtkVBox(FALSE, 5)
	layoutDataInputRight$packStart(FRFilesInput, expand = FALSE, fill = FALSE)

# whole frame layout
layoutDataInputBody <- gtkHBox(FALSE, 5)
	layoutDataInputBody$packStart(layoutDataInputLeft, expand = FALSE, fill = FALSE)
	layoutDataInputBody$packStart(layoutDataInputRight, expand = TRUE, fill = TRUE)
LBLDataInputFrame <- gtkLabel("Please choose the format and source of your data input and import the files.")
LBLDataInputFrame$setSizeRequest(-1, 25)
layoutDataInput <- gtkVBox(FALSE, 5)
	layoutDataInput$packStart(LBLDataInputFrame, expand = FALSE, fill = FALSE)
	layoutDataInput$packStart(layoutDataInputBody, expand = TRUE, fill = TRUE)

####
#### Data Layout Frame
######################

## The general data layout is determined by the number of plates (acquired
## through an entrybox) to be analysed and whether they are retrieved from a
## single or from multiple files (acquired through radio buttons). In order
## to avoid errors during the calculations it has to be clarified whether any
## non numerical data is present in those files (acquired through radio buttons).

BXLayout <- gtkVBox(FALSE, 5)
BXLayout$setBorderWidth(5)
FRLayout$setBorderWidth(3)
FRLayout$add(BXLayout)

BXDataLayoutPlate <- gtkHBox(FALSE, 5)
SEPDataLayoutPlate <- gtkLabel("")
BXDataLayoutMultipleLabel <- gtkHBox(FALSE, 5)
BXDataLayoutMultiple <- gtkHBox(FALSE, 5)
SEPDataLayoutMultiple <- gtkLabel("")
BXDataLayoutNumericalLabel <- gtkHBox(FALSE, 5)
BXDataLayoutNumerical <- gtkHBox(FALSE, 5)
	BXLayout$packStart(BXDataLayoutPlate, expand = FALSE, fill = FALSE)
	BXLayout$packStart(SEPDataLayoutPlate, expand = FALSE, fill = FALSE)
	BXLayout$packStart(BXDataLayoutMultipleLabel, expand = FALSE, fill = FALSE)
	BXLayout$packStart(BXDataLayoutMultiple, expand = FALSE, fill = FALSE)
	BXLayout$packStart(SEPDataLayoutMultiple, expand = FALSE, fill = FALSE)
	BXLayout$packStart(BXDataLayoutNumericalLabel, expand = FALSE, fill = FALSE)
	BXLayout$packStart(BXDataLayoutNumerical, expand = FALSE, fill = FALSE)

# Data Layout Platenumber
LBLDataLayoutPlate <- gtkLabel("How many plates do you want to analyse?")
ENTDataLayoutPlate <- gtkEntry()
ENTDataLayoutPlate$setSizeRequest(50, 20)
	BXDataLayoutPlate$packStart(LBLDataLayoutPlate, expand = FALSE, fill = FALSE)
	BXDataLayoutPlate$packStart(ENTDataLayoutPlate, expand = FALSE, fill = FALSE)

# Data Layout Single or Multiple Files
LBLDataLayoutMultiple <- gtkLabel("Do you have one document with all the data or one for each plate?")
	BXDataLayoutMultipleLabel$packStart(LBLDataLayoutMultiple, expand = FALSE, fill = FALSE)
	
btnDataLayoutMultipleN <- gtkRadioButton(group = NULL, "single document")
btnDataLayoutMultipleY <- gtkRadioButton(group = c(btnDataLayoutMultipleN), "multiple documents")
	BXDataLayoutMultiple$packStart(btnDataLayoutMultipleN, expand = FALSE, fill = FALSE)
	BXDataLayoutMultiple$packStart(btnDataLayoutMultipleY, expand = FALSE, fill = FALSE)

# Data Layout Numerical Data
LBLDataLayoutNumerical <- gtkLabel("Did you already clean all non numerical data?")
	BXDataLayoutNumericalLabel$packStart(LBLDataLayoutNumerical, expand = FALSE, fill = FALSE)
	
btnDataLayoutNumericalY <- gtkRadioButton(group = NULL, "yes")
btnDataLayoutNumericalN <- gtkRadioButton(group = c(btnDataLayoutNumericalY), "no")
	BXDataLayoutNumerical$packStart(btnDataLayoutNumericalY, expand = FALSE, fill = FALSE)
	BXDataLayoutNumerical$packStart(btnDataLayoutNumericalN, expand = FALSE, fill = FALSE)

####
#### Cutting Borders Frame
##########################

## In the original file output from the readout systems lots of information
## is stored in addition to the raw data. Since the layout of these files
## differs between devices the user has to specify where to reduce the files
## to only read the data. Since the information in the file headers - if present
## (aquired through radio buttons) - might be useful in a compressed way the 
## user can choose to save them all together in a separate file (aquired 
## through radio buttons). The row / column numbers are all acquired through entry boxes.
BXBorders <- gtkVBox(FALSE, 5)
BXBorders$setBorderWidth(5)
FRBorders$setBorderWidth(3)
FRBorders$add(BXBorders)

BXBordersHeader1Label <- gtkHBox(FALSE, 5) # header row 1
BXBordersHeader1 <- gtkHBox(FALSE, 5) # exists
BXBordersHeader2Label <- gtkHBox(FALSE, 5) # header row 2
BXBordersHeader2 <- gtkHBox(FALSE, 5) # size and remove
SEPBordersHeader <- gtkLabel("")
BXBordersColumnsLabel <- gtkHBox(FALSE, 5)
BXBordersColumns <- gtkHBox(FALSE, 5)
SEPBordersColumns <- gtkLabel("")
BXBordersRowsend <- gtkHBox(FALSE, 5)
	BXBorders$packStart(BXBordersHeader1Label, expand = FALSE, fill = FALSE)
	BXBorders$packStart(BXBordersHeader1, expand = FALSE, fill = FALSE)
	BXBorders$packStart(BXBordersHeader2Label, expand = FALSE, fill = FALSE)
	BXBorders$packStart(BXBordersHeader2, expand = FALSE, fill = FALSE)
	BXBorders$packStart(SEPBordersHeader, expand = FALSE, fill = FALSE)
	BXBorders$packStart(BXBordersColumnsLabel, expand = FALSE, fill = FALSE)
	BXBorders$packStart(BXBordersColumns, expand = FALSE, fill = FALSE)
	BXBorders$packStart(SEPBordersColumns, expand = FALSE, fill = FALSE)
	BXBorders$packStart(BXBordersRowsend, expand = FALSE, fill = FALSE)

# Does a Header exist?
LBLBordersHeader1 <- gtkLabel("Is a header included in the file(s)?") 
	BXBordersHeader1Label$packStart(LBLBordersHeader1, expand = FALSE, fill = FALSE)
	
btnBordersHeader1Y <- gtkRadioButton(group = NULL, "yes")
btnBordersHeader1N <- gtkRadioButton(group = c(btnBordersHeader1Y), "no")
	BXBordersHeader1$packStart(btnBordersHeader1Y, expand = FALSE, fill = FALSE)
	BXBordersHeader1$packStart(btnBordersHeader1N, expand = FALSE, fill = FALSE)

# Remove or save the Header?
LBLBordersHeader2 <- gtkLabel("How many rows of the file(s) are header(s), and what should be done?")
	BXBordersHeader2Label$packStart(LBLBordersHeader2, expand = FALSE, fill = FALSE)
	
btnBordersHeader2Y <- gtkRadioButton(group = NULL, "Remove header(s).")
btnBordersHeader2N <- gtkRadioButton(group = c(btnBordersHeader2Y), "Save header(s) to file.")
ENTHeader <- gtkEntry() #get entry for Headerheight
ENTHeader$setSizeRequest(50, 20)
	BXBordersHeader2$packStart(ENTHeader, expand = FALSE, fill = FALSE)
	BXBordersHeader2$packStart(btnBordersHeader2Y, expand = FALSE, fill = FALSE)
	BXBordersHeader2$packStart(btnBordersHeader2N, expand = FALSE, fill = FALSE)

# Columns to remove
LBLBordersColumns <- gtkLabel("Are there any columns in the document(s) that are irrelevant for the analysis?")
	BXBordersColumnsLabel$packStart(LBLBordersColumns, expand = FALSE, fill = FALSE)
	
ENTremoveStart <- gtkEntry()
ENTremoveStart$setSizeRequest(50, 20)
LBLBordersColumnsStart <- gtkLabel("columns in the beginning and")
ENTremoveEnd <- gtkEntry()
ENTremoveEnd$setSizeRequest(50, 20)
LBLBordersColumnsEnd <- gtkLabel("columns in the end have to be removed.")
	BXBordersColumns$packStart(ENTremoveStart, expand = FALSE, fill = FALSE)
	BXBordersColumns$packStart(LBLBordersColumnsStart, expand = FALSE, fill = FALSE)
	BXBordersColumns$packStart(ENTremoveEnd, expand = FALSE, fill = FALSE)
	BXBordersColumns$packStart(LBLBordersColumnsEnd, expand = FALSE, fill = FALSE)

# Rows end
LBLBordersRowsend <- gtkLabel("How many rows have to be deleted in the end of the document(s)?")
ENTRowsEnd <- gtkEntry()
ENTRowsEnd$setSizeRequest(50, 20)
	BXBordersRowsend$packStart(LBLBordersRowsend, expand = FALSE, fill = FALSE)
	BXBordersRowsend$packStart(ENTRowsEnd, expand = FALSE, fill = FALSE)

####
#### Files Input Frame
######################

## The number of rows for the file names and the well numbers is defined
## by a combination of the plate number and whether a single or multiple
## files shall be loaded. Each line contains an an entrybox for the well
## number of the plate and optionally an entrybox and filechooser button
## for the file resource. The maximum number of plates is ten since the
## interface is not generated procedurally. This could be changed if there
## is a need to analyse more than ten plates at a time.

BXFilesInput <- gtkVBox(FALSE, 5)
BXFilesInput$setBorderWidth(5)
FRFilesInput$setBorderWidth(3)
FRFilesInput$add(BXFilesInput)

BXFilesInputInstr <- gtkHBox(FALSE, 5)
BXFilesInputSeparator <- gtkHBox(FALSE, 5)
BXFilesInputHeader <- gtkHBox(FALSE, 5)
BXFileInput1 <- gtkHBox(FALSE, 5)
BXFileInput2 <- gtkHBox(FALSE, 5)
BXFileInput3 <- gtkHBox(FALSE, 5)
BXFileInput4 <- gtkHBox(FALSE, 5)
BXFileInput5 <- gtkHBox(FALSE, 5)
BXFileInput6 <- gtkHBox(FALSE, 5)
BXFileInput7 <- gtkHBox(FALSE, 5)
BXFileInput8 <- gtkHBox(FALSE, 5)
BXFileInput9 <- gtkHBox(FALSE, 5)
BXFileInput10 <- gtkHBox(FALSE, 5)
BXDataInputExecute <- gtkHBox(FALSE, 5)
	BXFilesInput$packStart(BXFilesInputInstr, expand = FALSE, fill = FALSE)
	BXFilesInput$packStart(BXFilesInputSeparator, expand = FALSE, fill = FALSE)
	BXFilesInput$packStart(BXFilesInputHeader, expand = FALSE, fill = FALSE)
	BXFilesInput$packStart(BXFileInput1, expand = FALSE, fill = FALSE)
	BXFilesInput$packStart(BXFileInput2, expand = FALSE, fill = FALSE)
	BXFilesInput$packStart(BXFileInput3, expand = FALSE, fill = FALSE)
	BXFilesInput$packStart(BXFileInput4, expand = FALSE, fill = FALSE)
	BXFilesInput$packStart(BXFileInput5, expand = FALSE, fill = FALSE)
	BXFilesInput$packStart(BXFileInput6, expand = FALSE, fill = FALSE)
	BXFilesInput$packStart(BXFileInput7, expand = FALSE, fill = FALSE)
	BXFilesInput$packStart(BXFileInput8, expand = FALSE, fill = FALSE)
	BXFilesInput$packStart(BXFileInput9, expand = FALSE, fill = FALSE)
	BXFilesInput$packStart(BXFileInput10, expand = FALSE, fill = FALSE)
	BXFilesInput$packEnd(BXDataInputExecute, expand = FALSE, fill = FALSE)

# Files Input Instructions
LBLFilesInputInstr <- gtkLabel("Insert Document Path to .csv-files starting within the current working directory.")
	BXFilesInputInstr$packStart(LBLFilesInputInstr, expand = FALSE, fill = FALSE)

# Files Input Separator
LBLFilesInputSeparator <- gtkLabel("Separator:")
ENTInputSeparator <- gtkEntry()
ENTInputSeparator$setSizeRequest(30, 20)
LBLFilesInputDecimal <- gtkLabel("Decimal separator:")
ENTInputDecimal <- gtkEntry()
ENTInputDecimal$setSizeRequest(30, 20)
	BXFilesInputSeparator$packStart(LBLFilesInputSeparator, expand = FALSE, fill = FALSE)
	BXFilesInputSeparator$packStart(ENTInputSeparator, expand = FALSE, fill = FALSE)
	BXFilesInputSeparator$packStart(LBLFilesInputDecimal, expand = FALSE, fill = FALSE)
	BXFilesInputSeparator$packStart(ENTInputDecimal, expand = FALSE, fill = FALSE)

# Files Input Header
LBLFilesInputHeader1 <- gtkLabel("Plate")
LBLFilesInputHeader2 <- gtkLabel("Document path")
LBLFilesInputHeader3 <- gtkLabel("Wells")
	BXFilesInputHeader$packStart(LBLFilesInputHeader1, expand = FALSE, fill = FALSE)
	BXFilesInputHeader$packStart(LBLFilesInputHeader2, expand = TRUE, fill = FALSE)
	BXFilesInputHeader$packEnd(LBLFilesInputHeader3, expand = FALSE, fill = FALSE)

# File Input replicates
# File 1
LBLFileInput1 <- gtkLabel("# 1: ")
ENTFileInputPath1 <- gtkEntry()
ENTFileInputPath1$setSizeRequest(-1, 20)
btnFileInput1 <- gtkButton()
IMDirectory1 <- gtkImageNewFromPixbuf(PBDirectory[[1]])
btnFileInput1$setImage(IMDirectory1)
ENTFileInputWell1 <- gtkEntry()
ENTFileInputWell1$setSizeRequest(40, 20)
	BXFileInput1$packStart(LBLFileInput1, expand = FALSE, fill = FALSE)
	BXFileInput1$packStart(ENTFileInputPath1, expand = TRUE, fill = TRUE)
	BXFileInput1$packStart(btnFileInput1, expand = FALSE, fill = FALSE)
	BXFileInput1$packEnd(ENTFileInputWell1, expand = FALSE, fill = FALSE)
# File 2
LBLFileInput2 <- gtkLabel("# 2: ")
ENTFileInputPath2 <- gtkEntry()
ENTFileInputPath2$setSizeRequest(-1, 20)
btnFileInput2 <- gtkButton()
IMDirectory2 <- gtkImageNewFromPixbuf(PBDirectory[[1]])
btnFileInput2$setImage(IMDirectory2)
ENTFileInputWell2 <- gtkEntry()
ENTFileInputWell2$setSizeRequest(40, 20)
	BXFileInput2$packStart(LBLFileInput2, expand = FALSE, fill = FALSE)
	BXFileInput2$packStart(ENTFileInputPath2, expand = TRUE, fill = TRUE)
	BXFileInput2$packStart(btnFileInput2, expand = FALSE, fill = FALSE)
	BXFileInput2$packEnd(ENTFileInputWell2, expand = FALSE, fill = FALSE)
# File 3
LBLFileInput3 <- gtkLabel("# 3: ")
ENTFileInputPath3 <- gtkEntry()
ENTFileInputPath3$setSizeRequest(-1, 20)
btnFileInput3 <- gtkButton()
IMDirectory3 <- gtkImageNewFromPixbuf(PBDirectory[[1]])
btnFileInput3$setImage(IMDirectory3)
ENTFileInputWell3 <- gtkEntry()
ENTFileInputWell3$setSizeRequest(40, 20)
	BXFileInput3$packStart(LBLFileInput3, expand = FALSE, fill = FALSE)
	BXFileInput3$packStart(ENTFileInputPath3, expand = TRUE, fill = TRUE)
	BXFileInput3$packStart(btnFileInput3, expand = FALSE, fill = FALSE)
	BXFileInput3$packEnd(ENTFileInputWell3, expand = FALSE, fill = FALSE)
# File 4
LBLFileInput4 <- gtkLabel("# 4: ")
ENTFileInputPath4 <- gtkEntry()
ENTFileInputPath4$setSizeRequest(-1, 20)
btnFileInput4 <- gtkButton()
IMDirectory4 <- gtkImageNewFromPixbuf(PBDirectory[[1]])
btnFileInput4$setImage(IMDirectory4)
ENTFileInputWell4 <- gtkEntry()
ENTFileInputWell4$setSizeRequest(40, 20)
	BXFileInput4$packStart(LBLFileInput4, expand = FALSE, fill = FALSE)
	BXFileInput4$packStart(ENTFileInputPath4, expand = TRUE, fill = TRUE)
	BXFileInput4$packStart(btnFileInput4, expand = FALSE, fill = FALSE)
	BXFileInput4$packEnd(ENTFileInputWell4, expand = FALSE, fill = FALSE)
# File 5
LBLFileInput5 <- gtkLabel("# 5: ")
ENTFileInputPath5 <- gtkEntry()
ENTFileInputPath5$setSizeRequest(-1, 20)
btnFileInput5 <- gtkButton()
IMDirectory5 <- gtkImageNewFromPixbuf(PBDirectory[[1]])
btnFileInput5$setImage(IMDirectory5)
ENTFileInputWell5 <- gtkEntry()
ENTFileInputWell5$setSizeRequest(40, 20)
	BXFileInput5$packStart(LBLFileInput5, expand = FALSE, fill = FALSE)
	BXFileInput5$packStart(ENTFileInputPath5, expand = TRUE, fill = TRUE)
	BXFileInput5$packStart(btnFileInput5, expand = FALSE, fill = FALSE)
	BXFileInput5$packEnd(ENTFileInputWell5, expand = FALSE, fill = FALSE)
# File 6
LBLFileInput6 <- gtkLabel("# 6: ")
ENTFileInputPath6 <- gtkEntry()
ENTFileInputPath6$setSizeRequest(-1, 20)
btnFileInput6 <- gtkButton()
IMDirectory6 <- gtkImageNewFromPixbuf(PBDirectory[[1]])
btnFileInput6$setImage(IMDirectory6)
ENTFileInputWell6 <- gtkEntry()
ENTFileInputWell6$setSizeRequest(40, 20)
	BXFileInput6$packStart(LBLFileInput6, expand = FALSE, fill = FALSE)
	BXFileInput6$packStart(ENTFileInputPath6, expand = TRUE, fill = TRUE)
	BXFileInput6$packStart(btnFileInput6, expand = FALSE, fill = FALSE)
	BXFileInput6$packEnd(ENTFileInputWell6, expand = FALSE, fill = FALSE)
# File 7
LBLFileInput7 <- gtkLabel("# 7: ")
ENTFileInputPath7 <- gtkEntry()
ENTFileInputPath7$setSizeRequest(-1, 20)
btnFileInput7 <- gtkButton()
IMDirectory7 <- gtkImageNewFromPixbuf(PBDirectory[[1]])
btnFileInput7$setImage(IMDirectory7)
ENTFileInputWell7 <- gtkEntry()
ENTFileInputWell7$setSizeRequest(40, 20)
	BXFileInput7$packStart(LBLFileInput7, expand = FALSE, fill = FALSE)
	BXFileInput7$packStart(ENTFileInputPath7, expand = TRUE, fill = TRUE)
	BXFileInput7$packStart(btnFileInput7, expand = FALSE, fill = FALSE)
	BXFileInput7$packEnd(ENTFileInputWell7, expand = FALSE, fill = FALSE)
# File 8
LBLFileInput8 <- gtkLabel("# 8: ")
ENTFileInputPath8 <- gtkEntry()
ENTFileInputPath8$setSizeRequest(-1, 20)
btnFileInput8 <- gtkButton()
IMDirectory8 <- gtkImageNewFromPixbuf(PBDirectory[[1]])
btnFileInput8$setImage(IMDirectory8)
ENTFileInputWell8 <- gtkEntry()
ENTFileInputWell8$setSizeRequest(40, 20)
	BXFileInput8$packStart(LBLFileInput8, expand = FALSE, fill = FALSE)
	BXFileInput8$packStart(ENTFileInputPath8, expand = TRUE, fill = TRUE)
	BXFileInput8$packStart(btnFileInput8, expand = FALSE, fill = FALSE)
	BXFileInput8$packEnd(ENTFileInputWell8, expand = FALSE, fill = FALSE)
# File 9
LBLFileInput9 <- gtkLabel("# 9: ")
ENTFileInputPath9 <- gtkEntry()
ENTFileInputPath9$setSizeRequest(-1, 20)
btnFileInput9 <- gtkButton()
IMDirectory9 <- gtkImageNewFromPixbuf(PBDirectory[[1]])
btnFileInput9$setImage(IMDirectory9)
ENTFileInputWell9 <- gtkEntry()
ENTFileInputWell9$setSizeRequest(40, 20)
	BXFileInput9$packStart(LBLFileInput9, expand = FALSE, fill = FALSE)
	BXFileInput9$packStart(ENTFileInputPath9, expand = TRUE, fill = TRUE)
	BXFileInput9$packStart(btnFileInput9, expand = FALSE, fill = FALSE)
	BXFileInput9$packEnd(ENTFileInputWell9, expand = FALSE, fill = FALSE)
# File 10
LBLFileInput10 <- gtkLabel("# 10: ")
ENTFileInputPath10 <- gtkEntry()
ENTFileInputPath10$setSizeRequest(-1, 20)
btnFileInput10 <- gtkButton()
IMDirectory10 <- gtkImageNewFromPixbuf(PBDirectory[[1]])
btnFileInput10$setImage(IMDirectory10)
ENTFileInputWell10 <- gtkEntry()
ENTFileInputWell10$setSizeRequest(40, 20)
	BXFileInput10$packStart(LBLFileInput10, expand = FALSE, fill = FALSE)
	BXFileInput10$packStart(ENTFileInputPath10, expand = TRUE, fill = TRUE)
	BXFileInput10$packStart(btnFileInput10, expand = FALSE, fill = FALSE)
	BXFileInput10$packEnd(ENTFileInputWell10, expand = FALSE, fill = FALSE)

# Create vectors containing all entryboxes for files and wellnumbers,
# the filechooser buttons and all horizontal boxes for input files.
VARFileInputVectorPaths <- c(ENTFileInputPath1, ENTFileInputPath2, ENTFileInputPath3, ENTFileInputPath4, ENTFileInputPath5, ENTFileInputPath6, ENTFileInputPath7, ENTFileInputPath8, ENTFileInputPath9, ENTFileInputPath10)
VARFileInputVectorWells<- c(ENTFileInputWell1, ENTFileInputWell2, ENTFileInputWell3, ENTFileInputWell4, ENTFileInputWell5, ENTFileInputWell6, ENTFileInputWell7, ENTFileInputWell8, ENTFileInputWell9, ENTFileInputWell10)
VARFileInputVectorButtons <- c(btnFileInput1, btnFileInput2, btnFileInput3, btnFileInput4, btnFileInput5, btnFileInput6, btnFileInput7, btnFileInput8, btnFileInput9, btnFileInput10)
VARFileInputVectorWhole <- c(BXFileInput1, BXFileInput2, BXFileInput3, BXFileInput4, BXFileInput5, BXFileInput6, BXFileInput7, BXFileInput8, BXFileInput9, BXFileInput10, "extra")
# "extra" entry is necessary for counting at a later point to not get stuck at 11.

#########################################################################################
#### Data Input Interactive
#########################################################################################

####
#### Signal: Number of Plates to analyse
########################################
## The input text is converted to be numeric. If it's greater than ten only the second
## error message is shown. If it's less than one only the first error message is shown.
## Only if the number is between one and ten the handler proceeds with saving the number
## to SETDataLayout$platenumber and adapting the rows displayed in the file input.
## First all unnecessary input lines are hidden and then all those needed are shown.
## - Error message 1 "-- Please enter a positive number for number of plates! --"
## - Error message 2 "-- Max. number of plates is 10! --"
ERRplatenum1 <- gtkLabel("-- Please enter a positive number for number of plates! --") #Errormessage if text is entered.
	ERRplatenum1["visible"] <- FALSE
	BXErrormessages$packStart(ERRplatenum1, expand = TRUE, fill = TRUE)
ERRplatenum2 <- gtkLabel("-- Max. number of plates is 10! --") #Errormessage if number is too big.
	ERRplatenum2["visible"] <- FALSE
	ERRplatenum2["visible"] <- FALSE
	BXErrormessages$packStart(ERRplatenum2, expand = TRUE, fill = TRUE)
	
gSignalConnect(ENTDataLayoutPlate, "activate", quote({
	text <- tryCatch(as.numeric(ENTDataLayoutPlate$getText()), warning = function(W) { # convert to numeric
		ERRplatenum1["visible"] <- TRUE 
		ERRplatenum2["visible"] <- FALSE
	})
	if (is.numeric(text) == TRUE & is.na(text) == FALSE & text > 10) { # more than 10 plates
		ERRplatenum1["visible"] <- FALSE
		ERRplatenum2["visible"] <- TRUE
	} else if (is.numeric(text) == TRUE & is.na(text) == FALSE & text <= 0) { # 0 or less plates
		ERRplatenum1["visible"] <- TRUE 
		ERRplatenum2["visible"] <- FALSE
	} else if (is.numeric(text) == TRUE & is.na(text) == FALSE & text > 0 & text <= 10) {
		SETDataLayout$platenumber <- text
		ERRplatenum1["visible"] <- FALSE
		ERRplatenum2["visible"] <- FALSE
		for (i in text:10) { #hide all inputlines for plates not needed
			VARFileInputVectorWhole[[i+1]]["visible"] <- FALSE # here we need the 11th element
		}
		for (j in 1:text) { #show all inputlines for plates needed (in case they were hidden earlier)
			VARFileInputVectorWhole[[j]]["visible"] <- TRUE
		}
	}
	#print(SETDataLayout$platenumber)
}))

####
#### Signal: Single document or multiple ones?
##############################################
## If the "No" button is active all file input entryboxes and filechooser buttons
## but the first one are hidden from the user interface and all extra file destinations are
## deleted from the settings. If multiple files are to be loaded all ten 
## boxes and buttons are shown.
## Only the given number of plates will be visible since the whole vertical
## boxes of the extra lines are hidden. The setting SETDataLayout$multiple is changed
## accordingly.
gSignalConnect(btnDataLayoutMultipleN, "toggled", quote({
	if (btnDataLayoutMultipleN$getActive() == TRUE) { #single document
		SETDataLayout$multiple <- FALSE
		for (i in 2:10) { #hide all input lines for document paths
			VARFileInputVectorPaths[[i]]["visible"] <- FALSE
			VARFileInputVectorButtons[[i]]["visible"] <- FALSE
		}
		SETFilesInput$files <- SETFilesInput$files[1] #delete all values for paths besides 1
	} else { #multiple documents
		SETDataLayout$multiple <- TRUE
		for (i in 1:10) { #show all vector paths
			VARFileInputVectorPaths[[i]]["visible"] <- TRUE
			VARFileInputVectorButtons[[i]]["visible"] <- TRUE
		}
	}
	#print(SETDataLayout$multiple)
}))

####
#### Signal: Nonnumerical Data cleaned?
#######################################
## If the "yes" button is toggled the setting SETDataLayout$missingValues is set
## to FALSE, otherwise to TRUE.
gSignalConnect(btnDataLayoutNumericalY, "toggled", quote({
	if (btnDataLayoutNumericalY$getActive() == TRUE) { #data cleaned
		SETDataLayout$missingValues <- FALSE
	} else { #still data like NA or >9 ...
		SETDataLayout$missingValues <- TRUE
	}
	#print(SETDataLayout$missingValues)
}))

####
#### Signal: Selection whether Header is there or not.
######################################################
## If the "yes" radio button is toggled the line of additional option is shown,
## otherwise it is hidden. The setting SETBorders$header is changed accordingly.
## Afterwards the signal for a changed header length is emitted in order to update
## the associated error message.
gSignalConnect(btnBordersHeader1Y, "toggled", quote({
	if (btnBordersHeader1Y$getActive() == TRUE) { # Header is included.
		SETBorders$header <- TRUE
		BXBordersHeader2Label["visible"] <- TRUE # show additional options.
		BXBordersHeader2["visible"] <- TRUE
	} else { # Header is not included
		SETBorders$header <- FALSE
		BXBordersHeader2Label["visible"] <- FALSE # hide additional options.
		BXBordersHeader2["visible"] <- FALSE}
	gSignalEmit(ENTHeader, "activate")
	#print(SETBorders$header)
}))

####
#### Signal: Entry for Header length
####################################
## If there is a header included in the files the text in the entrybox is
## converted to numeric and checked to be positive. If it is positive it is
## saved to SETBorder$rowsTop and the error message is hidden. Otherwise the error
## message is displayed. If no header is included in the files the setting remains
## untouched and the error is hidden.

## - Error message "-- Please enter a positive number for Header length! --"
ERRHeader <- gtkLabel("-- Please enter a positive number for Header length! --")
	ERRHeader["visible"] <- FALSE
	BXErrormessages$packStart(ERRHeader, expand = TRUE, fill = TRUE)
	
gSignalConnect(ENTHeader, "activate", quote({
	if (SETBorders$header == TRUE) {
	text <- tryCatch(as.numeric(ENTHeader$getText()), warning = function(W) ERRHeader["visible"] <- TRUE) # try to convert to numeric
		if (is.numeric(text) == TRUE & is.na(text) == FALSE & text < 0) { # show error if number was smaller than 0
			ERRHeader["visible"] <- TRUE
		} else if (is.numeric(text) == TRUE & is.na(text) == FALSE) { # only option left is a positive number so we save it
			SETBorders$rowsTop <- text
			ERRHeader["visible"] <- FALSE
		}
	} else { # no header required
		ERRHeader["visible"] <- FALSE
	}
	#print(SETBorders$rowsTop)
}))

####
#### Signal: Selection what to do with the removed headers.
###########################################################
## The setting SETBorders$remove is set to TRUE if the file headers
## are to be discarded and FALSE if they shall be saved in a separate
## file.
gSignalConnect(btnBordersHeader2Y, "toggled", quote({
	if (btnBordersHeader2Y$getActive() == TRUE) { #header is to be removed
		SETBorders$remove <- TRUE
	} else { #header is to be saved
		SETBorders$remove <- FALSE
	}
	#print(SETBorders$remove)
}))

####
#### Signals: Columns to delete
###############################
## The entryboxes for the columns to remove to the left / right of the data are
## handled the same. They first try to convert the entered text to numeric. If it is
## a positive number it is saved to SETBorders$removeStart / -$removeEnd. Two variables
## are used to save whether both settings got correct entries. If at least one of them is FALSE
## the error message is shown and only when both are TRUE it is hidden.
## - Error message "-- Please enter positive numbers or 0 for spare columns! --"
ERRColumns <- gtkLabel("-- Please enter positive numbers or 0 for spare columns! --")
	ERRColumns["visible"] <- FALSE
	BXErrormessages$packStart(ERRColumns, expand = TRUE, fill = TRUE)
	
VARValidRemoveStart <- TRUE #Is there a correct value for removeStart entered?
VARValidRemoveEnd <- TRUE #Is there a correct value for removeEnd entered?

gSignalConnect(ENTremoveStart, "activate", quote({
	text <- tryCatch(as.numeric(ENTremoveStart$getText()), warning = function(W) VARValidRemoveStart <<- FALSE )# try to convert to numeric
	if (is.numeric(text) == TRUE & is.na(text) == FALSE & text < 0) { # negative number
		VARValidRemoveStart <- FALSE
	} else if (is.numeric(text) == TRUE & is.na(text) == FALSE) { # positive number
		SETBorders$removeStart <- text
		VARValidRemoveStart <- TRUE
	}
	if (VARValidRemoveStart == TRUE & VARValidRemoveEnd == TRUE) { # only remove error message when both values are correct.
		ERRColumns["visible"] <- FALSE
	} else {
		ERRColumns["visible"] <- TRUE
	}
	#print(SETBorders$removeStart)
}))

gSignalConnect(ENTremoveEnd, "activate", quote({
	text <- tryCatch(as.numeric(ENTremoveEnd$getText()), warning = function(W) VARValidRemoveEnd <<- FALSE ) # try to convert to numeric
	if (is.numeric(text) == TRUE & is.na(text) == FALSE & text < 0) { # negative number
		VARValidRemoveEnd <- FALSE
	} else if (is.numeric(text) == TRUE & is.na(text) == FALSE) { # positive number
		SETBorders$removeEnd <- text
		VARValidRemoveEnd <- TRUE
	}
	if (VARValidRemoveStart == TRUE & VARValidRemoveEnd == TRUE) { #only remove error message when both values are correct.
		ERRColumns["visible"] <- FALSE
	} else {
		ERRColumns["visible"] <- TRUE
	}
	#print(SETBorders$removeEnd)
}))

####
#### Signal: Rows to delete in the end
######################################
## The text from the entrybox is converted to be numeric. If it is a positive number
## it is saved to SETBorders$rowsEnd and the error message is hidden. Otherwise the error
## message is shown.

## - Error message "-- Please enter positive numbers or 0 for spare rows! --"
ERRRows <- gtkLabel("-- Please enter positive numbers or 0 for spare rows! --")
	ERRRows["visible"] <- FALSE
	BXErrormessages$packStart(ERRRows, expand = TRUE, fill = TRUE)

gSignalConnect(ENTRowsEnd, "activate", quote({
	text <- tryCatch(as.numeric(ENTRowsEnd$getText()), warning = function(W) ERRRows["visible"] <- TRUE) # convert to numeric
	if (is.numeric(text) == TRUE & is.na(text) == FALSE & text < 0) {
		ERRRows["visible"] <- TRUE
	} else if (is.numeric(text) == TRUE & is.na(text) == FALSE) {
		SETBorders$rowsEnd <- text
		ERRRows["visible"] <- FALSE
	}
}))

####
#### Signal: CSV separators
###########################
## The cell / decimal separator is directly saved from the entrybox to the
## setting SETFileInput$separator / -$decimal respectively.
gSignalConnect(ENTInputSeparator, "activate", quote({
	text <- ENTInputSeparator$getText()
	SETFilesInput$separator <- text
}))

gSignalConnect(ENTInputDecimal, "activate", quote({
	text <- ENTInputDecimal$getText()
	SETFilesInput$decimal <- text
}))

####
#### Signals: Input filenames and well numbers
##############################################
## In this section only the signal handlers for the filechooser buttons are connected
## to the corresponding entryboxes. The actual file names and well numbers are processed
## from "Data Input Execute" section.
## - Error message 1 "-- Please enter positive numbers for wells! --"
## - Error message 2 "-- Entered paths don't lead to existing files! --"
ERRwellnum <- gtkLabel("-- Please enter positive numbers for wells! --")
	ERRwellnum["visible"] <- FALSE
	BXErrormessages$packStart(ERRwellnum, expand = TRUE, fill = TRUE)
ERRfilemode <- gtkLabel("-- Entered paths don't lead to existing files! --")
	ERRfilemode["visible"] <- FALSE
	BXErrormessages$packStart(ERRfilemode, expand = TRUE, fill = TRUE)

gSignalConnect(btnFileInput1, "clicked", quote(FFileChooserOpen(ENTFileInputPath1)))
gSignalConnect(btnFileInput2, "clicked", quote(FFileChooserOpen(ENTFileInputPath2)))
gSignalConnect(btnFileInput3, "clicked", quote(FFileChooserOpen(ENTFileInputPath3)))
gSignalConnect(btnFileInput4, "clicked", quote(FFileChooserOpen(ENTFileInputPath4)))
gSignalConnect(btnFileInput5, "clicked", quote(FFileChooserOpen(ENTFileInputPath5)))
gSignalConnect(btnFileInput6, "clicked", quote(FFileChooserOpen(ENTFileInputPath6)))
gSignalConnect(btnFileInput7, "clicked", quote(FFileChooserOpen(ENTFileInputPath7)))
gSignalConnect(btnFileInput8, "clicked", quote(FFileChooserOpen(ENTFileInputPath8)))
gSignalConnect(btnFileInput9, "clicked", quote(FFileChooserOpen(ENTFileInputPath9)))
gSignalConnect(btnFileInput10, "clicked", quote(FFileChooserOpen(ENTFileInputPath10)))

#########################################################################################
#### Data Input Execute
#########################################################################################

## The main data set used in this section is "Data_input". It contains the freshly loaded
## data and is initialized with the content "empty" = "empty". This is used throughout
## the program to reset data.frames and to check their content.
Data_input <- data.frame( "empty" = "empty" )

# Create Execute button
btnDataInputExecute <- gtkButton("Import Files")
	BXDataInputExecute$packEnd(btnDataInputExecute, expand = FALSE, fill = FALSE)
	
# Create vector with all Settings to check again before importing the files.
CheckInputDataInput <- c(btnBordersHeader1Y, btnBordersHeader2Y, ENTHeader, btnDataLayoutMultipleN, ENTremoveStart, ENTremoveEnd, ENTRowsEnd, ENTDataLayoutPlate, btnDataLayoutNumericalY, ENTInputSeparator, ENTInputDecimal)

##############################
#### Function: FCheckDataInput
##############################
## This function triggers the signal handlers of all input widgets on the Data Input screen
## besides the file names and well numbers for each plate. It works with a previously
## defined vector containing all widget names as "Input", detects their class and emits the
## corresponding signal.
FCheckDataInput <- function(Input) {
	for (i in 1:length(Input)) {
		if (class(Input[[i]])[1] == "GtkRadioButton") {
			gSignalEmit(Input[[i]], "toggled")
		} else if (class(Input[[i]])[1] == "GtkEntry") {
			gSignalEmit(Input[[i]], "activate")
		}
	}
}

################################
#### Function: FFileInputCollect
################################
## This function collects all file names and well numbers from the entryboxes.
## If only one file is to be loaded the path in the first entrybox is checked for
## file existence. If it does exist the path is saved to SETFilesInput$files[1],
## the rest of the vector is deleted and the error message is hidden. If it doesn't
## exist the whole vector is deleted and the error message is displayed.
#### In the case of multiple files the paths are checked procedurally. If the current
## file exists the files vector is replaced by all paths already checked. If one file
## exist the vector is emptied, the error message is displayed and the loop is broken.
#### The well numbers are also checked procedurally. After converting the entry to a
## numerical value and given that it's positive it is saved together with the
## previously checked numbers to SETFilesInput$wells. If it's negative the error
## message is shown and all the numbers are deleted from the settings.
FFileInputCollect <- function() {
	# Collect paths from all the fields and check on them
	if (SETDataLayout$multiple == FALSE) { #one path to be imported
		if (file.exists(ENTFileInputPath1$getText()) == TRUE) { #does the file exist?
			SETFilesInput$files[1] <<- ENTFileInputPath1$getText()
			ERRfilemode["visible"] <- FALSE
			SETFilesInput$files <<- SETFilesInput$files[1]
		} else {
			ERRfilemode["visible"] <- TRUE
			SETFilesInput$files <<- c()
		}
	} else { #multiple paths to be imported
		for (i in 1:SETDataLayout$platenumber) { #check on every path that should be entered
			path <- VARFileInputVectorPaths[[i]]$getText()
			if (file.exists(path) == TRUE) {
				SETFilesInput$files[i] <<- path
				ERRfilemode["visible"] <- FALSE
				SETFilesInput$files <<- SETFilesInput$files[1:i]
			} else {
				ERRfilemode["visible"] <- TRUE
				SETFilesInput$files <<- c()
				break
			}
		}
	}
	
	# Collect well numbers from all the fields and check on them
	for (i in 1:SETDataLayout$platenumber) { #check for every plate whether there is a positive number
		number <- tryCatch(as.numeric(VARFileInputVectorWells[[i]]$getText()), warning = function(W) ERRwellnum["visible"] <- TRUE )
		if (is.numeric(number) == TRUE & is.na(number) == FALSE & number > 0) {
			SETFilesInput$wells[i] <<- number
			ERRwellnum["visible"] <- FALSE
			SETFilesInput$wells <<- SETFilesInput$wells[1:i]
		} else {
			ERRwellnum["visible"] <- TRUE
			SETFilesInput$wells <<- c()
			break
		}
	}
}

#################################
#### Function: FCheckDataImported
#################################
## This function checks whether the given parameter actually fit the data loaded.
FCheckDataImported <- function(D) {
#### First it goes through all the values and checks whether they are numerical. If the
## class of a column is either numeric or integer it checks every single value to be
## defined. If it find any false columns or NA values a popup appears, the data frame
## is reset and the function returns FALSE.
	for (i in 1:dim(D)[2]) {
		Temp <- D[,i]
		if (class(Temp) != "numeric" & class(Temp) != "integer") {
			POPImportFail <- gtkMessageDialog(mainApplication, "destroy-with-parent", "error", "ok", "Imported data is not numeric!")
			if (class(POPImportFail$run()) == "integer") POPImportFail$destroy()
			Data_input <<- data.frame( "empty" = "empty" )
			return(FALSE)
		} else {
			for (j in 1:length(Temp)) {
				if (is.na(Temp[j]) == TRUE) {
					POPImportFail <- gtkMessageDialog(mainApplication, "destroy-with-parent", "error", "ok", "Imported data is not numeric!")
					if (class(POPImportFail$run()) == "integer") POPImportFail$destroy()
					Data_input <<- data.frame( "empty" = "empty" )
					return(FALSE)
				}
			}
		}
	}
	
#### Given that the first step went well the next step is to count the columns
## of the imported data. The second dimension of the data frame should equal the
## sum of the given well numbers. If it doesn't a popup appears, the data frame
## is reset and the function returns FALSE.
	wellsum <- sum(SETFilesInput$wells)
	if (dim(D)[2] != (wellsum + 1)) {
		POPImportFail <- gtkMessageDialog(mainApplication, "destroy-with-parent", "error", "ok", "Number of columns doesn't match total number of wells")
		if (class(POPImportFail$run()) == "integer") POPImportFail$destroy()
		Data_input <<- data.frame( "empty" = "empty" )
		return(FALSE)
	}
	
#### If the column number is correct the data frame is next checked for unique
## column names. If there are any dublicates a popup appears, the data frame
## is reset and the function returns FALSE.
	wellnames <- as.factor(names(D))
	if (length(levels(wellnames)) != length(names(D))) {
		POPImportFail <- gtkMessageDialog(mainApplication, "destroy-with-parent", "error", "ok", "Wellnumbers in imported data are not unique!")
		if (class(POPImportFail$run()) == "integer") POPImportFail$destroy()
		Data_input <<- data.frame( "empty" = "empty" )
		return(FALSE)
	}
	
#### Last but not least the function checks whether the data fits the template,
## given that the latter had already been filled. If the column names / well numbers
## don't equal each other a popup appears, which tells the user to synchronise the data
## and the template. In contrast to the previous check ups this one doesn't reset
## the data and always returns TRUE, since the data is generally valid.
	if (Template[1,1] != "empty") {
		wellnamesData <- as.factor(names(D)[2:dim(D)[2]])
		wellnamesTemplate <- as.factor(Template$X)
		for (i in 1:length(wellnamesData)) {
			if (levels(wellnamesData)[i] != levels(wellnamesTemplate)[i]) {
				POPTemplateFail <- gtkMessageDialog(mainApplication, "destroy-with-parent", "error", "ok", "Wellnumbers in template and imported data don't match, please correct the template!")
				if (class(POPTemplateFail$run()) == "integer") POPTemplateFail$destroy()
				return(TRUE)
			}
		}
	}
	
	# else
	return(TRUE)
}

################################
#### Signal: Import Files button
################################
## Upon clicking the "Import files" button the previously described functions are
## called and the data is loaded from the file(s) according to the given parameters.
gSignalConnect(btnDataInputExecute, "clicked", quote({

#### First all boxes and radio buttons are activated by calling FCheckDataInput in order to
## definitely acquire all settings. Then all file names and well numbers are collected by
## calling FFileInputCollect. If the user chose valid parameters all error messages
## regarding the Data Input (index 1:6) should be invisible.
	FCheckDataInput(CheckInputDataInput)
	FFileInputCollect()
	Errormessages <- BXErrormessages$getChildren()
	counter <- 0
	for (i in 1:6) {
		if (Errormessages[[i]]["visible"] == TRUE) {
			counter <- counter + 1
		}
	}
	
## If any of these messages is still visible a popup labelled "Please solve all status
## messages and try again." is generated and the signal handler reaches its end.
	if (counter > 0) {
		
		# Popup for Import failed
		POPImportFail <- gtkMessageDialog(mainApplication, "destroy-with-parent", "error", "ok", "Please solve all status messages and try again.")
		if (POPImportFail$run() == GtkResponseType["ok"]) POPImportFail$destroy()
		
	} else {
		
## Otherwise a popup saying "Importing file(s) ..." is generated and the actual
## import process starts.
		POPImportRunning <- gtkMessageDialog(mainApplication, "destroy-with-parent", "message", "none", "Importing file(s) ...")
		Sys.sleep(.1)
			
#### In order to handle the data sets during the import a list is generated, which
## contains one element per file to be loaded.
		DataInputList <- list()
		if (SETDataLayout$multiple == TRUE) {
			for (i in 1:SETDataLayout$platenumber) {
				DataInputList[[paste("Input",i,sep="")]] <- data.frame()
			}
		} else {
			DataInputList[["Input1"]] <- data.frame()
		}
		
#### After that the files are read using the specified separators. Depending on the header
## settings the first lines of each file are either
## - ignored if there is no header
## - skipped and ignored if the user doesn't want it saved separately
## - or skipped and read separately if the user wants it saved.
## In the latter case the header collection will be saved when starting the analysis.
		if (SETBorders$header == FALSE) {
			for (i in 1:length(DataInputList)) {
				DataInputList[[paste("Input",i,sep="")]] <- read.csv(SETFilesInput$files[i], sep = SETFilesInput$separator, header = TRUE, check.names = FALSE, dec = SETFilesInput$decimal, blank.lines.skip = FALSE)
			}
		} else {
			Header <- data.frame(0)
			for (i in 1:length(DataInputList)) {
				DataInputList[[paste("Input",i,sep="")]] <- read.csv(SETFilesInput$files[i], skip = SETBorders$rowsTop, sep = SETFilesInput$separator, header = TRUE, check.names = FALSE, dec = SETFilesInput$decimal, blank.lines.skip = FALSE)
				if (SETBorders$remove == FALSE) {
					Header <<- data.frame(Header, read.csv(SETFilesInput$files[i], nrows = SETBorders$rowsTop, sep = SETFilesInput$separator, header = FALSE, check.names = FALSE, dec = SETFilesInput$decimal, blank.lines.skip = FALSE), check.rows = FALSE)
				}
			}
			Header <- Header[,-1]
		}
		#print("Header")
		
#### After successfully loading the data the extra columns in the beginning and the end
## and the extra rows in the end of each data frame are removed.
		if (SETBorders$removeStart != 0) {
			for (i in 1:length(DataInputList)) {
				DataInputList[[paste("Input",i,sep="")]] <- DataInputList[[paste("Input",i,sep="")]][,-c(1:SETBorders$removeStart)]
			}
		}
		if (SETBorders$removeEnd != 0) {
			for (i in 1:length(DataInputList)) {
				last <- dim(DataInputList[[paste("Input",i,sep="")]])[2]
				DataInputList[[paste("Input",i,sep="")]] <- DataInputList[[paste("Input",i,sep="")]][,-c((last -SETBorders$removeEnd +1):last)]
			}
		}
		
		if (SETBorders$rowsEnd > 0) {
			for (i in 1:length(DataInputList)) {
				last <- dim(DataInputList[[paste("Input",i,sep="")]])[1]
				DataInputList[[paste("Input",i,sep="")]] <- DataInputList[[paste("Input",i,sep="")]][-c((last -SETBorders$rowsEnd +1):last),]
			}
		}
		
#### If the user announced that there is non numerical data in the files these values
## are replaced by zero. After the conversion the replacements will be indicated in
## a popup window. Therefore a column and a single value counter are used. First
## this procedure goes through all columns of the data set. If a columns class is
## "factor" it is replaced by zeros. Otherwise it will go through all values in the
## column and check whether they are NA after casting them as numeric.
		counter <- 0
		column <- 0
		if (SETDataLayout$missingValues == TRUE) {
			POPImportReplace <- gtkMessageDialog(mainApplication, "destroy-with-parent", "error", "ok", "All nonnumerical data will be replaced with '0'.")
			if (POPImportReplace$run() == GtkResponseType["ok"]) POPImportReplace$destroy()
			
			#### Go through all values
			for (i in 1:length(DataInputList)) {
				for (j in 1:dim(DataInputList[[paste("Input",i,sep="")]])[2]) {
					## replace factor columns
					if (class(DataInputList[[paste("Input",i,sep="")]][,j]) == "factor") {
						DataInputList[[paste("Input",i,sep="")]][,j] <- c(rep(0,dim(DataInputList[[paste("Input",i,sep="")]])[1]))
						column <- column +1
						next
					}
					for (k in 1:dim(DataInputList[[paste("Input",i,sep="")]])[1]) {
						if (is.na(as.numeric(DataInputList[[paste("Input",i,sep="")]][k,j])) == TRUE) {
							DataInputList[[paste("Input",i,sep="")]][k,j] <- 0
							counter <- counter +1
						}
					}
				}
			}
			
			#### show popups
			if (column > 0) {
				POPImportReplace <- gtkMessageDialog(mainApplication, "destroy-with-parent", "error", "ok", paste(column, "whole column(s) had to be replaced. If you want them included clean nonumerical data manually. The first five rows are printed to the R-Console.", sep=" "))
				if (POPImportReplace$run() == GtkResponseType["ok"]) POPImportReplace$destroy()
			}
			if (counter > 0) {
				POPImportReplace <- gtkMessageDialog(mainApplication, "destroy-with-parent", "error", "ok", paste(counter, "single value(s) had to be replaced.", sep=" "))
				if (POPImportReplace$run() == GtkResponseType["ok"]) POPImportReplace$destroy()
			} else {
				POPImportReplace <- gtkMessageDialog(mainApplication, "destroy-with-parent", "error", "ok", "There were no single values replaced.")
				if (POPImportReplace$run() == GtkResponseType["ok"]) POPImportReplace$destroy()
			}
		}
		#print("Values")
		
#### After all these steps the loaded data sets have to be fused into one.
## If there is more than one data set the time points have to be controlled.
## For this every first column of the data sets is compared to that of the first
## data set. If that fails a popup appears, the data frame is reset and the
## function jumps to its last step.
		proceed <- 1
		if (SETDataLayout$multiple == FALSE) {
			Data_input <<- DataInputList[["Input1"]]
			names(Data_input)[1] <- "X"
		} else {
			Data_input <- DataInputList[["Input1"]][,1:2]
			
			#### Check on timepoints
			for (i in 1:length(DataInputList)) {
				for (j in 1:dim(Data_input)[1]) {
					if (DataInputList[[paste("Input",i,sep="")]][j,1] != Data_input[j,1]) {
						proceed <- 0
						break
					}
				}
				if (proceed == 0) break
			}
			if (proceed == 0) {
				POPImportFail <- gtkMessageDialog(mainApplication, "destroy-with-parent", "error", "ok", "Imported Files don't have the same timepoints. Please solve the problem and try again.")
				if (POPImportFail$run() == GtkResponseType["ok"]) POPImportFail$destroy()
				Data_input <- data.frame("empty" = "empty")
			} else {
				for (i in 1:length(DataInputList)) {
					Data_input <- data.frame(Data_input, DataInputList[[paste("Input",i,sep="")]][ c(1:dim(Data_input)[1]), c(2:dim(DataInputList[[paste("Input",i,sep="")]])[2]) ], check.names = FALSE)
				}
				names(Data_input)[1] <- "X"
			}
			Data_input <- Data_input[,-2]
		}
		#print("Fusion")

#### If the data could be fused, but more than one column was of type factor
## the first five rows of the data set are printed to the R-console.
#### Lastly the function FCheckDataImported is called with Data_input as
## parameter. If the data is okay its checksum is saved to TEMPChecksums (see
## section Run Analysis) and either way a popup informs the user about the
## success of the import.
		if (column > 0 & proceed == 1) print(Data_input[1:5,])
		
		if (FCheckDataImported(Data_input) == TRUE) {
			TEMPChecksums$Data_input <- sum(colSums(Data_input))
			POPImportRunning[["text"]] <- "Data was succesfully imported."
			POPImportRunning$addButton("Okay", GtkResponseType["ok"])
			POPImportRunning$run()
		} else {
			POPImportRunning[["text"]] <- "Data was not imported."
			POPImportRunning$addButton("Okay", GtkResponseType["ok"])
			POPImportRunning$run()
		}
		#print(Data_input)
		POPImportRunning$destroy()
	}
}))