#########################################################################################
#### Programming Concept and Variable Naming
#########################################################################################

## The whole code is organised corresponding to the 8 different interfaces, which are
## navigated by the buttons at the top and bottom of the application.
## For each of these interfaces there is a layout, interactive and executive section in
## the respective file. Those are all loaded when launching the program by the code in
## in this main file. Prior to this the currently running R session is emptied and
## prepared, and the main window of the application is created. In addition to the main
## files there is one version specific file providing extra interface elements and
## functions. This can be replaced by any of the other version files without creating any
## conflicts (besides a changed checksum).
## All variables created throughout the code are either accessible in the global
## environment of R, or through the corresponding function that creates them. Each
## variable begins with one of the abbreviations listed below.

## - FR = Frame
## - BX = Box eg. BXHeaderH1 = horizontal Box number 1 for Frame Header
## - DA = Drawing Area
## - SET = List containing settings for a certain section
## - btn = Button, Radiobutton
## - CKB = Checkbox
## - LBL = Label containing text
## - ENT = Entrybox
## - ERR = Errormessage corresponding to a certain event.
## - POP = Popup
## - F = function
## - SCR = Scrolled Window
## - SCB = ScaleBar
## - PB = PixBuf
## - IM = gtkImage
## - ARR = Arrow
## - VEC = numeric or character vector
## - VAR = single variable

## The only exception from this is the toplevel window which is named "mainApplication".

#########################################################################################
#### R Session Preparation
#########################################################################################

## First all existing global objects are removed, since overwriting already existing
## variable names, e.g. when restarting the program, would cause errors to occur.
rm(list = ls())
print("All R objects were deleted")

## Then all the required packages are loaded:
## RGtk2 is needed as the interface between R and GTK.
library("RGtk2")
## gWidgets and gWidgetsRGtk2 are cross dependencies of RGtk2.
library("gWidgets")
library("gWidgetsRGtk2")
## stats, graphics and utils are packages normally loaded by default, but since a user
## might have changed his defaults they are loaded once again.
library("stats")
library("graphics")
library("utils")
## The package tools is needed for md5checksum creation.
library("tools")
## drc is the package utilised for IC50 calculation.
library("drc")
## cairoDevice is required for the display of graphics and for the utilisation of
## different graphical output surfaces.
library("cairoDevice")

####
#### Notes on Operating Systems
###############################

## There several cases in which system specific functions are needed. This is further
## explained in the corresponding functions. Besides this there are some general
## differences. One is that on Microsoft Windows systems buttons can only have either an
## icon or a label, which affects many buttons opening a file chooser.

#########################################################################################
#### Main Window Creation and Layout
#########################################################################################

## The toplevel window is called mainApplication. Its default size is set to 1100 x 700
## pixels. If the screensize is smaller than this the default is set to 90% of the screen
## and the window is maximized for optimal view. The toplevel layout consists of one line
## of buttons at the top and one at the bottom, which either open popups or determine the
## content of the frame in the center.

mainApplication <- gtkWindow("toplevel", show = FALSE)
mainApplication$setDefaultSize(1100,700)
if (gdkScreenGetDefault()$getWidth() < 1100 | gdkScreenGetDefault()$getHeight() < 700) {
	mainApplication$setDefaultSize((0.9*gdkScreenGetDefault()$getWidth()), (0.9*gdkScreenGetDefault()$getHeight()))
	mainApplication$maximize()
}
mainApplication$set(title = "TReCCA Analyser - for time resolved cell culture assays - V4.0")

####
#### Top row
############

## In the top row one button for each step that leads to the analysis is included.
## These steps are:
## - Defining the DATA INPUT
## - Selecting all LABELS & COLOURS of the lines
## - Choosing the ANALYSIS OPTIONS
## - Entering all GRAPH OPTIONS
## - RUN ANALYSIS
## At the end of the top row a help button is added, which tells the user to
## consult the manual, this documentation, any R forum, or the developers directly.

# Buttons for input Settings and starting the analysis
btnDataInput <- gtkButton("Data input")
btnLabels <- gtkButton("Labels & colours")
btnAnalysis <- gtkButton("Analysis options")
btnPlotOptions <- gtkButton("Graph options")
btnRun <- gtkButton("Run analysis")
# This will not work on windows systems:
ARRbtnRun <- gtkArrow(arrow.type = "GTK_ARROW_RIGHT")
btnRun$setImage(ARRbtnRun)

topRowButtons <- gtkHButtonBox(TRUE)
	topRowButtons$packStart(btnDataInput, expand = FALSE, fill = FALSE)
	topRowButtons$packStart(btnLabels, expand = FALSE, fill = FALSE)
	topRowButtons$packStart(btnAnalysis, expand = FALSE, fill = FALSE)
	topRowButtons$packStart(btnPlotOptions, expand = FALSE, fill = FALSE)
	topRowButtons$packStart(btnRun, expand = FALSE, fill = FALSE)

# Button for Help including signal handler
btnHelp <- gtkButton("Help")
gSignalConnect(btnHelp, "clicked", quote({
	POPHelp <- gtkMessageDialog(mainApplication, "destroy-with-parent", "error", "ok",
	"To get help please see the detailed user manual in the program folder. For a quick guide please also see the user manual.")
	if (length(POPHelp$run()) == 1) POPHelp$destroy()
}))

# Top row Layout
topRow <- gtkHBox(FALSE, 5)
	topRow$packStart(topRowButtons, expand = FALSE, fill = FALSE)
	topRow$packEnd(btnHelp, expand = FALSE, fill = FALSE)

####
#### Bottom row
###############

## In the bottom row all interfaces associated with import and export of either
## setting or data are located. These are:
## - Viewing and export of GRAPHical OUTPUT
## - DATA OUTPUT in csv tables
## - IMPORT/EXPORT of all SETINGS made in the session
## - IMPORT/EXPORT of the whole project as R-DATA file
## In the middle of the bottom row an extra frame for status messages is added.
## This is used to display error messages for invalid input to the interface.

# Bottom row buttons
btnSettings <- gtkButton("Import/export settings")
btnRData <- gtkButton("Import/export R-data")
btnGraphs <- gtkButton("Graph output")
btnDataOutput <- gtkButton("Data output")
bottomRowLeftButtons <- gtkHButtonBox(TRUE)
	bottomRowLeftButtons$packStart(btnGraphs, expand = FALSE, fill = FALSE)
	bottomRowLeftButtons$packStart(btnDataOutput, expand = FALSE, fill = FALSE)
bottomRowRightButtons <- gtkHButtonBox(TRUE)
	bottomRowRightButtons$packStart(btnSettings, expand = FALSE, fill = FALSE)
	bottomRowRightButtons$packStart(btnRData, expand = FALSE, fill = FALSE)

# Status messages frame
FRError <- gtkFrame("Status messages")
SCRErrormessages <- gtkScrolledWindow()
SCRErrormessages$setPolicy("automatic", "automatic")
SCRErrormessages$setSizeRequest(-1, 20)
BXErrormessages <- gtkVBox(TRUE, 3)
	FRError$add(SCRErrormessages)
	SCRErrormessages$addWithViewport(BXErrormessages)

# Bottom row layout
bottomRow <- gtkHBox(FALSE, 5)
	bottomRow$packStart(bottomRowLeftButtons, expand = FALSE, fill = FALSE)
	bottomRow$packStart(FRError, expand = TRUE, fill = TRUE)
	bottomRow$packStart(bottomRowRightButtons, expand = FALSE, fill = FALSE)

####
#### Center Frame
#################

## The frame in the center consists of a scrolled window with a viewport containing 
## the main content. Directly after startup some general notes are displayed. Those are
## the currently used version of the program and the working directory, as well as
## notes for orientation. These tell you where to start a new project (top left), to
## view and export results (bottom left) and where to save or load the project (bottom
## right). Later on this screen can't be reached anymore.
FRCenter <- gtkFrame(label = "Welcome")
FRCenter$setBorderWidth(5)
SCRCenter <- gtkScrolledWindow()
	SCRCenter$setPolicy("automatic", "automatic")
VPCenter <- gtkViewport()
# Note where to start a new project:
BXProjectStartNew <- gtkHBox(FALSE,5)
BXProjectStartNew$setBorderWidth(10)
BXProjectStartNewInt <- gtkVBox(FALSE, 5)
ARRProjectStartNew <- gtkArrow(arrow.type = "GTK_ARROW_UP")
LBLProjectStartNew <- gtkLabel("start / modify a project")
	BXProjectStartNew$packStart(BXProjectStartNewInt, expand = FALSE, fill = FALSE)
	BXProjectStartNewInt$packStart(ARRProjectStartNew, expand = FALSE, fill = FALSE)
	BXProjectStartNewInt$packStart(LBLProjectStartNew, expand = FALSE, fill = FALSE)
# Notes on any import and export
BXProjectViewExport <- gtkHBox(FALSE,5)
BXProjectViewExport$setBorderWidth(10)
BXProjectView <- gtkVBox(FALSE, 5)
ARRProjectView <- gtkArrow(arrow.type = "GTK_ARROW_DOWN")
LBLProjectView <- gtkLabel("view and export results")
BXProjectLoad <- gtkVBox(FALSE, 5)
ARRProjectLoad <- gtkArrow(arrow.type = "GTK_ARROW_DOWN")
LBLProjectLoad <- gtkLabel("save / load a project")
	BXProjectViewExport$packStart(BXProjectView, expand = FALSE, fill = FALSE)
	BXProjectView$packStart(LBLProjectView, expand = FALSE, fill = FALSE)
	BXProjectView$packStart(ARRProjectView, expand = FALSE, fill = FALSE)
	BXProjectViewExport$packEnd(BXProjectLoad, expand = FALSE, fill = FALSE)
	BXProjectLoad$packStart(LBLProjectLoad, expand = FALSE, fill = FALSE)
	BXProjectLoad$packStart(ARRProjectLoad, expand = FALSE, fill = FALSE)
# Welcome Note:
LBLWelcome <- gtkLabel("Welcome to the TReCCA Analyser - the analysis program for time resolved cell culture assays.")
LBLCurrentWd <- gtkLabel(paste("The current working directory is: ",getwd(), sep = ""))
LBLWDInfo <- gtkLabel("If you change the working directory please restart the application.")
SEPWelcome <- gtkLabel("")
SEPWelcome$setSizeRequest(-1, 50)
# Packing of startup screen:
BXCenterFrame <- gtkVBox(FALSE, 5)
	BXCenterFrame$packStart(BXProjectStartNew, expand = FALSE, fill = FALSE)
	BXCenterFrame$packStart(LBLWelcome, expand = TRUE, fill = TRUE)
	BXCenterFrame$packEnd(BXProjectViewExport, expand = FALSE, fill = FALSE)
	BXCenterFrame$packEnd(SEPWelcome, expand = FALSE, fill = FALSE)
	BXCenterFrame$packEnd(LBLWDInfo, expand = FALSE, fill = FALSE)
	BXCenterFrame$packEnd(LBLCurrentWd, expand = FALSE, fill = FALSE)
FRCenter$add(SCRCenter)
	SCRCenter$add(VPCenter)
		VPCenter$add(BXCenterFrame)

# ###
# ### Whole window layout
# #######################

verticalBuild <- gtkVBox(FALSE, 5)
verticalBuild$setBorderWidth(5)
	verticalBuild$packStart(topRow, expand = FALSE, fill = FALSE)
	verticalBuild$packStart(FRCenter, expand = TRUE, fill = TRUE)
	verticalBuild$packStart(bottomRow, expand = FALSE, fill = FALSE)
mainApplication$add(verticalBuild)

#########################################################################################
#### Main Navigation Functionality
#########################################################################################

####
#### Function: FExchangeMenu
############################

## This function is used to switch between the main menus displayed in the center frame.
## Its arguments are labelButton, which is the label of the menu button clicked and
## layoutBox, which is the box containing the content of the corresponding menu.
## First the function removes the first and only child element from the central viewport.
## Then it will set the label of the center frame to the given labelButton and add the
## new layoutBox to the viewport. Since removing and restoring a drawing area - which
## is used on the graph output screen - is not possible without causing a severe error
## an exception for this case is implemented. Before removing the layout, the label is
## checked, and if it was Graph Output the drawing area is destroyed and replaced by a
## label. After this the function proceeds normally.

FExchangeMenu <- function(labelButton, layoutBox){
	# Check whether the user leaves the graph output screen
	if (FRCenter$GetLabel() == "Graph output") {
		BXCurrentGraph$getChildren()[[1]]$destroy()
		LBLCurrentGraph <- gtkLabel("Please choose a graph from the right.")
		BXCurrentGraph$packStart(LBLCurrentGraph, expand = TRUE, fill = TRUE)
		LBLCurrentGraphData$setLabel("Current Data")
	}
	# remove current content
	centerChild <- VPCenter$GetChildren()
	VPCenter$remove(centerChild[[1]])
	# change label and add new content
	FRCenter$SetLabel(label = labelButton)
	VPCenter$add(layoutBox)
}

#### The signal handlers for the menu buttons each refer to the function FExchangeMenu.
gSignalConnect(btnDataInput, "clicked", quote(FExchangeMenu("Data Input", layoutDataInput)))
gSignalConnect(btnLabels, "clicked", quote(FExchangeMenu("Labels & Colours", layoutLabels)))
gSignalConnect(btnPlotOptions, "clicked", quote(FExchangeMenu("Graph options", layoutPlotOptions)))
gSignalConnect(btnAnalysis, "clicked", quote(FExchangeMenu("Analysis options", layoutAnalysis)))
gSignalConnect(btnGraphs, "clicked", quote(FExchangeMenu("Graph output", layoutGraphs)))
gSignalConnect(btnDataOutput, "clicked", quote(FExchangeMenu("Data output", layoutDataOutput)))


#########################################################################################
#### Global Functions
#########################################################################################

# Pixbuf containing the folder icon used on filechooser buttons
PBDirectory <- gdkPixbuf(width = 16, height = 16, filename = imagefile("gnome-fs-directory.png"))

####
#### Function: FFileChooserOpen
###############################

## Whenever a file has to be chosen this function is called. Its only argument is the
## entrybox in which the returned file name should be stored. All functions using this
## name will retrieve it from the entrybox. The function first calls the basic R
## function file.choose. Since on Microsoft windows systems encoding problems can occur
## the short path name is created and returned to the entrybox if the application is run
## on a Windows system. Otherwise the raw output of file.choose will be returned.
FFileChooserOpen <- function(entrybox) {
	path <- file.choose()
	if (Sys.info()["sysname"] == "Windows") path <- shortPathName(path)
	entrybox$setText(path)
}

####
#### Function: FCheckFileExistance
##################################

## Whenever a file is to be saved the target file path needs to be checked for existance.
## Its only argument is the path.
## If it does already exist, a popup is created and the user has to confirm writing over
## the already existing file. The function will either return TRUE or FALSE.
FCheckFileExistance <- function(path) {
	if (file.exists(path) == FALSE) return(TRUE)
	else {
		POPOverwriteFile <- gtkMessageDialog(mainApplication, "destroy-with-parent", type = "question", buttons = "yes-no", paste("Do you really want to overwrite the file ", path, "?", sep = ""))
		response <- POPOverwriteFile$run()
		if (response == GtkResponseType["yes"]) {
			POPOverwriteFile$destroy()
			return(TRUE)
		} else {
			POPOverwriteFile$destroy()
			return(FALSE)
		}
	}
}

#########################################################################################
#### Data Sets
#########################################################################################

## The data the application works on is handled in specific data frames. One data frame
## is created for each possible data set. Here all data sets are defined for the first
## time independently of the version which is run. The naming of the data sets is:
## Data_basicAvExtended, where basic can be one of raw, medium, oxoDish, oxoPlate or
## hydroPlate. The "Av" in the middle is optional and the Extended analysis step can be
## one of Orig (original data set), Sm (smoothed), Slope, SlopeSd, Cons (oxygen
## consumption), ConsSd, Sd (standard deviation) or Cal (only for HydroPlate). In
## addition there are three data objects for the IC50: Data_IC50, Data_IC50Basis and
## Data_IC50Models.

# Basic version data sets:
Data_raw <- data.frame()
Data_rawOrig <- data.frame()
Data_rawSm <- data.frame()
Data_rawSlope <- data.frame()
Data_rawSlopeSd <- data.frame()
Data_rawCons <- data.frame()
Data_rawConsSd <- data.frame()
Data_rawAv <- data.frame()
Data_rawAvSm <- data.frame()
Data_rawAvSlope <- data.frame()
Data_rawAvSlopeSd <- data.frame()
Data_rawAvCons <- data.frame()
Data_rawAvConsSd <- data.frame()
Data_rawSd <- data.frame()
Data_medium <- data.frame()
Data_mediumOrig <- data.frame()
Data_mediumSm <- data.frame()
Data_mediumSlope <- data.frame()
Data_mediumSlopeSd <- data.frame()
Data_mediumCons <- data.frame()
Data_mediumConsSd <- data.frame()
Data_mediumAv <- data.frame()
Data_mediumAvSm <- data.frame()
Data_mediumAvSlope <- data.frame()
Data_mediumAvSlopeSd <- data.frame()
Data_mediumAvCons <- data.frame()
Data_mediumAvConsSd <- data.frame()
Data_mediumSd <- data.frame()
Data_IC50 <- data.frame()
Data_IC50Basis <- data.frame()
Data_IC50Models <- list()

# 24 well version
Data_oxoDish <- data.frame()
Data_oxoDishOrig <- data.frame()
Data_oxoDishSm <- data.frame()
Data_oxoDishSlope <- data.frame()
Data_oxoDishSlopeSd <- data.frame()
Data_oxoDishCons <- data.frame()
Data_oxoDishConsSd <- data.frame()
Data_oxoDishAv <- data.frame()
Data_oxoDishAvSm <- data.frame()
Data_oxoDishAvSlope <- data.frame()
Data_oxoDishAvSlopeSd <- data.frame()
Data_oxoDishAvCons <- data.frame()
Data_oxoDishAvConsSd <- data.frame()
Data_oxoDishSd <- data.frame()

# 96 version
Data_oxoPlate <- data.frame()
Data_oxoPlateOrig <- data.frame()
Data_oxoPlateSm <- data.frame()
Data_oxoPlateSlope <- data.frame()
Data_oxoPlateSlopeSd <- data.frame()
Data_oxoPlateCons <- data.frame()
Data_oxoPlateConsSd <- data.frame()
Data_oxoPlateAv <- data.frame()
Data_oxoPlateAvSm <- data.frame()
Data_oxoPlateAvSlope <- data.frame()
Data_oxoPlateAvSlopeSd <- data.frame()
Data_oxoPlateAvCons <- data.frame()
Data_oxoPlateAvConsSd <- data.frame()
Data_oxoPlateSd <- data.frame()
Data_hydroPlate <- data.frame()
Data_hydroPlateOrig <- data.frame()
Data_hydroPlateCal <- data.frame()
Data_hydroPlateSm <- data.frame()
Data_hydroPlateSlope <- data.frame()
Data_hydroPlateSlopeSd <- data.frame()
Data_hydroPlateAv <- data.frame()
Data_hydroPlateAvSm <- data.frame()
Data_hydroPlateAvSlope <- data.frame()
Data_hydroPlateAvSlopeSd <- data.frame()
Data_hydroPlateSd <- data.frame()

#### In the object ListDataSets a short description for each data set is stored. This
## is used during procedural generation of interface elements or processing of all
## data sets.
ListDataSets <- c(	"Data_raw" = "Raw data", "Data_rawSm" = "Smoothed raw data", "Data_rawSlope" = "Slope raw data", "Data_rawSlopeSd" = "Deviation slope raw data", "Data_rawCons" = "Consumption from raw data", "Data_rawConsSd" = "Deviation consumption from raw data",
					"Data_rawAv" = "Average raw data", "Data_rawAvSm" = "Smoothed average raw data", "Data_rawAvSlope" = "Slope average raw data", "Data_rawAvSlopeSd" = "Deviation slope average raw data", "Data_rawAvCons" = "Consumption from average raw data", "Data_rawAvConsSd" = "Deviation consumption from average raw data", "Data_rawSd" = "Raw data standard deviation",
					"Data_oxoDish" = "OxoDish data", "Data_oxoDishSm" = "Smoothed OxoDish data", "Data_oxoDishSlope" = "Slope OxoDish data", "Data_oxoDishSlopeSd" = "Deviation slope OxoDish data", "Data_oxoDishCons" = "Consumption from OxoDish data", "Data_oxoDishConsSd" = "Deviation consumption from OxoDish data",
					"Data_oxoDishAv" = "Average OxoDish data", "Data_oxoDishAvSm" = "Smoothed average OxoDish data", "Data_oxoDishAvSlope" = "Slope average OxoDish data", "Data_oxoDishAvSlopeSd" = "Deviation slope average OxoDish data", "Data_oxoDishAvCons" = "Consumption from average OxoDish data", "Data_oxoDishAvConsSd" = "Deviation consumption from average OxoDish data", "Data_oxoDishSd" = "OxoDish data standard deviation",
					"Data_oxoPlate" = "OxoPlate data", "Data_oxoPlateSm" = "Smoothed OxoPlate data", "Data_oxoPlateSlope" = "Slope OxoPlate data", "Data_oxoPlateSlopeSd" = "Deviation slope OxoPlate data", "Data_oxoPlateCons" = "Consumption from OxoPlate data", "Data_oxoPlateConsSd" = "Deviation consumption from OxoPlate data",
					"Data_oxoPlateAv" = "Average OxoPlate data", "Data_oxoPlateAvSm" = "Smoothed average OxoPlate data", "Data_oxoPlateAvSlope" = "Slope average OxoPlate data", "Data_oxoPlateAvSlopeSd" = "Deviation slope average OxoPlate data", "Data_oxoPlateAvCons" = "Consumption from average OxoPlate data", "Data_oxoPlateAvConsSd" = "Deviation consumption from average OxoPlate data", "Data_oxoPlateSd" = "OxoPlate data standard deviation",
					"Data_hydroPlate" = "HydroPlate data", "Data_hydroPlateCal" = "Calibration data for pH consversion", "Data_hydroPlateSm" = "Smoothed HydroPlate data", "Data_hydroPlateSlope" = "Slope HydroPlate data", "Data_hydroPlateSlopeSd" = "Deviation slope HydroPlate data",
					"Data_hydroPlateAv" = "Average HydroPlate data", "Data_hydroPlateAvSm" = "Smoothed average HydroPlate data", "Data_hydroPlateAvSlope" = "Slope average HydroPlate data", "Data_hydroPlateAvSlopeSd" = "Deviation slope average HydroPlate data",  "Data_hydroPlateSd" = "HydroPlate data standard deviation",
					"Data_medium" = "Medium data", "Data_mediumSm" = "Smoothed medium data", "Data_mediumSlope" = "Slope medium data", "Data_mediumSlopeSd" = "Deviation slope medium data", "Data_mediumCons" = "Consumption from medium data", "Data_mediumConsSd" = "Deviation consumption from medium data",
					"Data_mediumAv" = "Average medium data", "Data_mediumAvSm" = "Smoothed average medium data", "Data_mediumAvSlope" = "Slope average medium data", "Data_mediumAvSlopeSd" = "Deviation slope average medium data", "Data_mediumAvCons" = "Consumption from average medium data", "Data_mediumAvConsSd" = "Deviation consumption from average medium data", "Data_mediumSd" = "Medium data standard deviation",
					"Data_rawOrig" = "Unformatted raw data", "Data_mediumOrig" = "Unformatted medium data", "Data_oxoDishOrig" = "Unformatted OxoDish data", "Data_oxoPlateOrig" = "Unformatted OxoPlate data", "Data_hydroPlateOrig" = "Unformatted HydroPlate data",
					"Data_IC50" = "IC50 data", "Data_IC50Basis" = "IC50 data basis", "Data_IC50Models" = "IC50 fitting data" )

#########################################################################################
#### Startup process
#########################################################################################

####
#### Control Checksum
#####################

## In order to prevent the user from using a modified version of the program without
## knowing it a checksum is used. This is created by another script and provided as a
## text file named qualitycontrol.txt. This value is then compared to the newly
## calculated md5sum. If they differ, a popup is produced, which has to be confirmed
## before the application actually opens. Additionally the title of the main window
## is changed.
con <- file("qualitycontrol.txt", open = "r")
filechecksumsloaded <- unserialize(con)
close(con)
rm(con)
files <- dir("Program")
for (i in 1:length(files)) {
	if (filechecksumsloaded[i] != md5sum(paste("Program", files[i], sep = "/"))) {
		POPProgramModified <- gtkMessageDialog(mainApplication, "destroy-with-parent", type = "error", buttons = "ok", "We hereby inform you that the TReCCA Analyser version you use has been modified. Any technical details or guidelines in the user manual might be invalid and you are prohibited to refer to this program unless you use the original version!")
		if (length(POPProgramModified$run()) == 1) POPProgramModified$destroy()
		mainApplication$set(title = "TReCCA Analyser - for time resolved cell culture assays - !! modified version !!")
		break
	}
}
rm(files)
rm(filechecksumsloaded)

####
#### Load the rest of the code
##############################

## After everything was prepared, all other source code files are loaded. First the six
## main menus are loaded in the order as they are in the interface. Then the version
## specific file and an optional style file are loaded. This contains additional
## elements for all of the previously loaded interfaces and the version information.
## The latter is necessary for the loading / saving of settings and for the correct
## flow of the analysis. The two code files for those two steps are the last ones to 
## be loaded.

# Source Data Input
# #################
source("Program/DataInput.R")

# Source Labels & colours
# #######################
source("Program/LabelsColours.R")

# Source Analysis Options
# #######################
source("Program/AnalysisOptions.R")

# Source Graph Options
# ####################
source("Program/GraphOptions.R")

# Source Graph Output
# ###################
source("Program/GraphOutput.R")

# Source Data output
# ##################
source("Program/DataOutput.R")

# Source Version Specific
# #######################
if (file.exists("Program/full.R") == TRUE) { source("Program/full.R")
} else if (file.exists("Program/24well.R") == TRUE) { source("Program/24well.R")
} else if (file.exists("Program/96well.R") == TRUE) { source("Program/96well.R")
} else if (file.exists("Program/base.R") == TRUE) source("Program/base.R")
# Style:
if (file.exists("Style.R")) source("Style.R")

# Import / Export
# ###############
source("Program/ImportExport.R")

# Run Analysis
# ############
source("Program/RunAnalysis.R")

####
#### Initialisation:
####################

## Finally after sourcing all the code the main window is set to be visible and
## the default_settings are loaded. Those default settings are designed for the full
## version, but can be loaded independently.

mainApplication$set("visible" = TRUE)

# Load default settings:
FLoadSettings("default_settings.txt")